@@ -809,7 +809,7 @@ bool Lockfile::lock(const char *name)
 
     for(;;) {
         fd = ::open(_path, O_WRONLY | O_CREAT | O_EXCL, 0660);
-        if(fd > 0) {
+        if(fd >= 0) {
             pid = getpid();
             snprintf(buffer, sizeof(buffer), "%d\n", pid);
             if(::write(fd, buffer, strlen(buffer)))
@@ -833,6 +833,8 @@ bool Lockfile::lock(const char *name)
         Thread::sleep(2000);
         status = ::read(fd, buffer, sizeof(buffer) - 1);
         if(status < 1) {
+            // ensure that buffer is null-terminated before continuing
+            buffer[sizeof(buffer) - 1] = '\0';
             ::close(fd);
             continue;
         }
