@@ -1558,9 +1558,11 @@ size_t Socket::address::print(const sockaddr* addr, char *dst, size_t dst_sz, bo
 {
     if(!addr || !dst || !dst_sz)
         return 0;
+
     memset(dst, 0, dst_sz);
     const char* ret = dst;
     const int af = addr->sa_family;
+    const char *res = NULL;
 #if defined(AF_INET6)
     ipv6_brackets = (af == AF_INET6) ? ipv6_brackets || port : false;
     if(ipv6_brackets) {
@@ -1568,7 +1570,6 @@ size_t Socket::address::print(const sockaddr* addr, char *dst, size_t dst_sz, bo
         dst_sz--;
     }
 #endif
-    const char * res;
     switch (af) {
 #ifdef  _MSWINDOWS_
     case AF_INET:
@@ -1576,16 +1577,20 @@ size_t Socket::address::print(const sockaddr* addr, char *dst, size_t dst_sz, bo
 		memset(&in, 0, sizeof(in));
 		in.sin_family = AF_INET;
 		memcpy(&in.sin_addr, &reinterpret_cast<const struct sockaddr_in*>(addr)->sin_addr, sizeof(struct in_addr));
-		getnameinfo((struct sockaddr *)&in, sizeof(struct sockaddr_in), dst, dst_sz, NULL, 0, NI_NUMERICHOST);
+		if(!getnameinfo((struct sockaddr *)&in, sizeof(struct sockaddr_in), dst, dst_sz, NULL, 0, NI_NUMERICHOST)) {
+			res = dst;
+		}
         break;
  #ifdef  AF_INET6
     case AF_INET6:
 		struct sockaddr_in6 in6;
 		memset(&in6, 0, sizeof(in6));
 		in6.sin6_family = AF_INET6;
-		memcpy(&in.sin_addr, &reinterpret_cast<const struct sockaddr_in6*>(addr)->sin6_addr, sizeof(struct in_addr6));
+		memcpy(&in6.sin6_addr, &reinterpret_cast<const struct sockaddr_in6*>(addr)->sin6_addr, sizeof(struct in_addr6));
 
-		getnameinfo((struct sockaddr *)&in6, sizeof(struct sockaddr_in6), dst, dst_sz, NULL, 0, NI_NUMERICHOST);
+		if(!getnameinfo((struct sockaddr *)&in6, sizeof(struct sockaddr_in6), dst, dst_sz, NULL, 0, NI_NUMERICHOST)) {
+			res = dst;
+		}
         break;
  #endif
 #elif  defined(HAVE_INET_NTOP)
@@ -1610,7 +1615,7 @@ size_t Socket::address::print(const sockaddr* addr, char *dst, size_t dst_sz, bo
     if(!res)
         return 0;
     size_t addr_len = strlen(res);
-    dst += addr_len;
+    dst = dst + addr_len;
     dst_sz -= addr_len;
 
 #if defined(AF_INET6)
@@ -3476,10 +3481,20 @@ int Socket::family(socket_t so)
     socklen_t len = sizeof(us.saddr);
     struct sockaddr *addr = (struct sockaddr *)(&us.saddr);
 
+#ifndef _MSWINDOWS_
     if(_getsockname_(so, addr, &len))
         return AF_UNSPEC;
 
     return us.inaddr.sin_family;
+#else
+    // getsockname doesn't work on unbound windows sockets
+    WSAPROTOCOL_INFO info;
+    len = sizeof(info);
+    if(getsockopt(so, SOL_SOCKET, SO_PROTOCOL_INFO, (char *) &info, &len))
+        return AF_UNSPEC;
+
+    return info.iAddressFamily;
+#endif
 }
 
 bool Socket::is_null(const char *str)
