@@ -15,7 +15,7 @@
 // You should have received a copy of the GNU Lesser General Public License
 // along with GNU uCommon C++.  If not, see <http://www.gnu.org/licenses/>.
 
-#if defined(OLD_STDCPP) || defined(NEW_STDCPP)
+#ifndef UCOMMON_SYSRUNTIME
 
 #include <ucommon-config.h>
 #include <ucommon/export.h>
@@ -47,18 +47,10 @@ using std::streambuf;
 using std::ios;
 
 StreamBuffer::StreamBuffer() :
-streambuf(),
-#ifdef OLD_STDCPP
-    iostream()
-#else
-    iostream((streambuf *)this)
-#endif
+streambuf(), iostream((streambuf *)this)
 {
     bufsize = 0;
     gbuf = pbuf = NULL;
-#ifdef OLD_STDCPP
-    init((streambuf *)this);
-#endif
 }
 
 int StreamBuffer::uflow()
