@@ -47,7 +47,7 @@ void HMAC::release(void)
 
 int __context::map_hmac(const char *type)
 {
-    if(eq_case(type, "sha") || eq_case(type, "sha1")) 
+    if(eq_case(type, "sha") || eq_case(type, "sha1") || eq_case(type, "sha160")) 
         return GNUTLS_MAC_SHA1;
     else if(eq_case(type, "sha256"))
         return GNUTLS_MAC_SHA256;
