@@ -20,7 +20,7 @@
  * @file ucommon/persist.h
  */
 
-#if defined(OLD_STDCPP) || defined(NEW_STDCPP)
+#ifndef UCOMMON_SYSRUNTIME
 #if !defined(_MSC_VER) || _MSC_VER >= 1400
 #ifndef _UCOMMON_PERSIST_H_
 #define _UCOMMON_PERSIST_H_
