@@ -28,6 +28,13 @@
 #define _UCOMMON_PLATFORM_H_
 #define UCOMMON_ABI 6
 
+#ifndef UCOMMON_SYSRUNTIME
+#ifndef NEW_STDCPP
+#define NEW_STDCPP
+#endif
+#define _UCOMMON_EXTENDED_
+#endif
+
 /**
  * Common namespace for all ucommon objects.
  * We are using a common namespace to easily separate ucommon from other
@@ -84,12 +91,6 @@
 #endif
 #endif
 
-// see if we are building for or using extended stdc++ runtime library support
-
-#if defined(__ANDROID__) || defined(NEW_STDCPP) || defined(OLD_STDCPP)
-#define _UCOMMON_EXTENDED_
-#endif
-
 // see if targeting legacy Microsoft windows platform
 
 #if defined(_MSC_VER) || defined(WIN32) || defined(_WIN32)
@@ -170,14 +171,10 @@ typedef int pid_t;
 #define __SHARED __EXPORT
 #endif
 
-#elif UCOMMON_VISIBILITY > 0
+#else
 #define __EXPORT    __attribute__ ((visibility("default")))
 #define __LOCAL     __attribute__ ((visibility("hidden")))
 #define __SHARED    __attribute__ ((visibility("default")))
-#else
-#define __EXPORT
-#define __LOCAL
-#define __SHARED
 #endif
 
 #ifdef  _MSWINDOWS_
@@ -188,12 +185,8 @@ typedef int pid_t;
 #include <io.h>
 
 // gcc c++11 support on mingw requires pthread support library
-#if (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ > 7)) && defined(_UCOMMON_EXTENDED_) && defined(__MINGW_WINPTHREAD__)
+#if (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ > 7)) && !defined(UCOMMON_SYSRUNTIME) && defined(__MINGW_WINPTHREAD__)
 #include <pthread.h>   // gnu libstdc++ now requires a win pthread
-#ifdef OLD_STDCPP
-#undef OLD_STDCPP
-#define NEW_STDCPP
-#endif
 #undef  _MSCONDITIONALS_
 #else   
 #define _MSTHREADS_
@@ -340,10 +333,13 @@ typedef void (*sighandler_t)(int);  /**< Convenient typedef for signal handlers.
 #endif
 typedef unsigned long timeout_t;    /**< Typedef for millisecond timer values. */
 
-#include <stdlib.h>
-#include <ctype.h>
-#include <limits.h>
-#include <errno.h>
+#include <cstdlib>
+#include <cctype>
+#include <climits>
+#include <cerrno>
+#ifndef UCOMMON_RUNTIME
+#include <new>
+#endif
 
 #ifdef  _MSWINDOWS_
 #ifndef ENETDOWN
@@ -433,7 +429,7 @@ typedef void (*cpr_service_t)(int argc, char **argv);
  */
 template<class T>
 inline T *init(T *memory)
-    {return ((memory) ? new(((caddr_t)memory)) T : NULL);}
+    {return ((memory) ? new(((void *)memory)) T : NULL);}
 
 typedef long Integer;
 typedef unsigned long Unsigned;
