@@ -31,7 +31,7 @@ void Digest::set(const char *type)
     release();
 
     // never use sha0
-    if(eq_case(type, "sha"))
+    if(eq_case(type, "sha") || eq_case(type, "sha160"))
         type = "sha1";
 
     hashtype = (void *)EVP_get_digestbyname(type);
